@@ -66,8 +66,10 @@ struct _ECalBackendExchangeTasksPrivate {
 	gint dummy;
 };
 
-#define PARENT_TYPE E_TYPE_CAL_BACKEND_EXCHANGE
-static ECalBackendExchange *parent_class = NULL;
+G_DEFINE_TYPE (
+	ECalBackendExchangeTasks,
+	e_cal_backend_exchange_tasks,
+	E_TYPE_CAL_BACKEND_EXCHANGE)
 
 static void
 get_from (ECalBackendSync *backend, ECalComponent *comp, gchar **from_name, gchar **from_addr)
@@ -854,6 +856,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (modtimes);
 		g_hash_table_destroy (attachments);
 		g_mutex_unlock (cbext->priv->mutex);
+		g_object_unref (cbext);
 		return status;
 	}
 
@@ -868,6 +871,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (attachments);
 		cbext->priv->is_loaded = TRUE;
 		g_mutex_unlock (cbext->priv->mutex);
+		g_object_unref (cbext);
 		return SOUP_STATUS_OK;
 	}
 
@@ -913,6 +917,7 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_ptr_array_free (hrefs, TRUE);
 		g_hash_table_destroy (attachments);
 		g_mutex_unlock (cbext->priv->mutex);
+		g_object_unref (cbext);
 		return status;
 	}
 
@@ -921,12 +926,14 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		g_hash_table_destroy (attachments);
 		cbext->priv->is_loaded = TRUE;
 		g_mutex_unlock (cbext->priv->mutex);
+		g_object_unref (cbext);
 		return SOUP_STATUS_OK;
 	}
 
 	ctx = exchange_account_get_context (cbex->account);
 	if (!ctx) {
 		g_mutex_unlock (cbext->priv->mutex);
+		g_object_unref (cbext);
 		/* This either means we lost connection or we are in offline mode */
 		return SOUP_STATUS_CANT_CONNECT;
 	}
@@ -967,6 +974,8 @@ get_changed_tasks (ECalBackendExchange *cbex)
 		cbext->priv->is_loaded = TRUE;
 
 	g_mutex_unlock (cbext->priv->mutex);
+	g_object_unref (cbext);
+
 	return status;
 }
 
@@ -981,7 +990,7 @@ notify_changes (E2kContext *ctx, const gchar *uri,
 	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (ecalbex));
 	g_return_if_fail (uri != NULL);
 
-	get_changed_tasks (ecalbex);
+	get_changed_tasks (g_object_ref (ecalbex));
 
 }
 
@@ -992,7 +1001,7 @@ authenticate_user_task (ECalBackendSync *backend, GCancellable *cancellable, ECr
 	GError *error = NULL;
 	ECalBackendExchangeTasks *cbext = E_CAL_BACKEND_EXCHANGE_TASKS (backend);
 
-	E_CAL_BACKEND_SYNC_CLASS (parent_class)->authenticate_user_sync (backend, cancellable, credentials, &error);
+	E_CAL_BACKEND_SYNC_CLASS (e_cal_backend_exchange_tasks_parent_class)->authenticate_user_sync (backend, cancellable, credentials, &error);
 	if (error) {
 		g_propagate_error (perror, error);
 		return;
@@ -1017,10 +1026,11 @@ authenticate_user_task (ECalBackendSync *backend, GCancellable *cancellable, ECr
 					E2K_CONTEXT_OBJECT_REMOVED, 30,
 					notify_changes, backend);
 
-	thread = g_thread_create ((GThreadFunc) get_changed_tasks, E_CAL_BACKEND_EXCHANGE (backend), FALSE, &error);
+	thread = g_thread_create ((GThreadFunc) get_changed_tasks, g_object_ref (backend), FALSE, &error);
 	if (!thread) {
 		g_propagate_error (perror, EDC_ERROR_EX (OtherError, error->message));
 		g_error_free (error);
+		g_object_unref (backend);
 	}
 }
 
@@ -1029,7 +1039,7 @@ refresh_task (ECalBackendSync *backend, EDataCal *cal, GCancellable *cancellable
 {
 	g_return_if_fail (E_IS_CAL_BACKEND_EXCHANGE (backend));
 
-	get_changed_tasks (E_CAL_BACKEND_EXCHANGE (backend));
+	get_changed_tasks (g_object_ref (backend));
 }
 
 struct _cb_data {
@@ -1466,21 +1476,6 @@ remove_task_object (ECalBackendSync *backend, EDataCal *cal, GCancellable *cance
 	g_propagate_error (error, EDC_ERROR_HTTP_STATUS (status));
 }
 
-static void
-init (ECalBackendExchangeTasks *cbext)
-{
-	cbext->priv = g_new0 (ECalBackendExchangeTasksPrivate, 1);
-
-	cbext->priv->mutex = g_mutex_new ();
-	cbext->priv->is_loaded = FALSE;
-}
-
-static void
-dispose (GObject *object)
-{
-	G_OBJECT_CLASS (parent_class)->dispose (object);
-}
-
 static void
 finalize (GObject *object)
 {
@@ -1494,26 +1489,33 @@ finalize (GObject *object)
 
 	g_free (cbext->priv);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (e_cal_backend_exchange_tasks_parent_class)->finalize (object);
 }
 
 static void
-class_init (ECalBackendExchangeTasksClass *klass)
+e_cal_backend_exchange_tasks_class_init (ECalBackendExchangeTasksClass *class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	ECalBackendSyncClass *sync_class = E_CAL_BACKEND_SYNC_CLASS (klass);
+	GObjectClass *object_class;
+	ECalBackendSyncClass *sync_class;
 
-	parent_class = g_type_class_peek_parent (klass);
+	object_class = G_OBJECT_CLASS (class);
+	object_class->finalize = finalize;
 
+	sync_class = E_CAL_BACKEND_SYNC_CLASS (class);
 	sync_class->authenticate_user_sync = authenticate_user_task;
 	sync_class->refresh_sync = refresh_task;
 	sync_class->create_object_sync = create_task_object;
 	sync_class->modify_object_sync = modify_task_object;
 	sync_class->remove_object_sync = remove_task_object;
 	sync_class->receive_objects_sync = receive_task_objects;
-
-	object_class->dispose = dispose;
-	object_class->finalize = finalize;
 }
 
-E2K_MAKE_TYPE (e_cal_backend_exchange_tasks, ECalBackendExchangeTasks, class_init, init, PARENT_TYPE)
+static void
+e_cal_backend_exchange_tasks_init (ECalBackendExchangeTasks *cbext)
+{
+	cbext->priv = g_new0 (ECalBackendExchangeTasksPrivate, 1);
+
+	cbext->priv->mutex = g_mutex_new ();
+	cbext->priv->is_loaded = FALSE;
+}
+
